import { useEffect, useState } from 'react'
import { Link, useParams, useNavigate } from 'react-router-dom'
import ReactMarkdown from 'react-markdown'
import axios from 'axios'
import { API_BASE_URL } from '@/config'
import MainArea from '@/components/layout/MainArea'
import { WikiIdBus } from '@/lib/eventBus/WikiIdBus'


export default () => {
  const { name } = useParams ()

  const navigate = useNavigate ()

  const [markdown, setMarkdown] = useState<string | null> (null)

  useEffect (() => {
    if (/^\d+$/.test (name))
      {
        void (axios.get (`${ API_BASE_URL }/wiki/${ name }`)
              .then (res => navigate (`/wiki/${ res.data.title }`, { replace: true })))
        return
      }

    void (axios.get (`${ API_BASE_URL }/wiki/title/${ encodeURIComponent (name) }`)
          .then (res => {
            setMarkdown (res.data.body)
            WikiIdBus.set (res.data.id)
          })
          .catch (() => setMarkdown ('')))
  }, [name])

  return (
      <MainArea>
        <div className="prose mx-auto p-4">
          {markdown == null ? 'Loading...' : (
              <>
                <ReactMarkdown components={{ a: (
                    ({ href, children }) => (['/', '.'].some (e => href?.startsWith (e))
                                             ? <Link to={href!}>{children}</Link>
                                             : <a href={href} target="_blank" rel="noopener noreferrer">{children}</a>)) }}>
                  {markdown || `このページは存在しません。[新規作成してください](/wiki/new?title=${ name })。`}
                </ReactMarkdown>
              </>)}
        </div>
      </MainArea>)
}
